
class TypesTestCases:
    type_default = 'default'
    type_405 = '405'
    type_params = 'params'
    type_elem = 'elem'
    type_gen = 'generation_data'
    type_health = 'health'
    type_env = 'env'